<?php
/*
 Simple:Press Plugin Title: Editor (TinyMCE - Rich Text)
 Version: 1.1
 Plugin URI: http://simple-press.com
 Description: Rich Text Editor using TinyMCE
 Author: Andy Staines & Steve Klasen
 Author URI: http://simple-press.com
 Simple:Press Versions: 5.1 and above
 */

if (preg_match('#'.basename(__FILE__).'#', $_SERVER['PHP_SELF'])) die('Access denied - you cannot directly call this file');

define('SPTMDB', 1);

# ======================================
# EDITOR CONSTANTS
#       Must be one of:
#       RICHTEXT        - 1
#       HTML            - 2
#       BBCODE          - 3
# ======================================
define('RICHTEXT',              1);
define('RICHTEXTNAME',  'TinyMCE');

# ======================================
# CONSTANTS USED BY THIS PLUGIN
# ======================================
define('SPTMDIR',                   SFPLUGINDIR.'tinymce-richtext/');
define('SPTMTMSCRIPT',      SFPLUGINURL.'tinymce-richtext/tinymce/');
define('SPTMSPSCRIPT',      SFPLUGINURL.'tinymce-richtext/resources/jscript/');
define('SPTMCSS',                   SFPLUGINURL.'tinymce-richtext/resources/css/');
define('SPTMCONTENTCSS',    SFPLUGINURL.'tinymce-richtext/tinymce/themes/advanced/skins/o2k7/');

# ======================================
# ACTIONS/FILTERS USED BY THUS PLUGIN
# ======================================
add_action('sph_activate_tinymce-richtext/sp-tinymce-plugin.php',           'sp_tinymce_install');
 add_action('sph_deactivate_tinymce-richtext/sp-tinymce-plugin.php',     'sp_tinymce_uninstall');
 add_filter('sph_plugins_active_buttons',                                                            'sp_tinymce_uninstall_option', 10, 2);
 add_action('init',                                                                                                          'sp_tinymce_localisation');
 add_action('sph_load_editor_support',                                                               'sp_tinymce_load_filters', 1, 1);
 add_action('sph_load_editor',                                                                               'sp_tinymce_load');
 add_filter('sph_editor_textarea',                                                                       'sp_tinymce_textarea', 1, 5);
 add_filter('sph_acknowledgements',                                                                      'sp_tinymce_acknowledgement');
 add_action('sph_admin_menu',                                                                            'sp_tinymce_admin_menu');
 add_filter('sph_admin_help-admin-components',                                               'sp_tinymce_admin_help', 10, 3);
 add_filter('sph_ProfilePostingOptionsFormEditors',                                          'sp_tinymce_profile_option', 1, 2);
 add_action('admin_footer',                                                                  'sp_tinymce_upgrade');
 add_action('sph_plugin_update_tinymce-richtext/sp-tinymce-plugin.php',  'sp_tinymce_upgrade');

# ======================================
# CONTROL FUNCTIONS USED BY THUS PLUGIN
# ======================================

# ----------------------------------------------
# Run Install Script on Activation action
# ----------------------------------------------
function sp_tinymce_install() {
         include_once(SPTMDIR.'sp-tinymce-install.php');
         sp_tinymce_do_install();
}

# ----------------------------------------------
# Run Uninstall Script on Uninstall actiopn
# ----------------------------------------------
function sp_tinymce_uninstall() {
         include_once(SPTMDIR.'sp-tinymce-uninstall.php');
         sp_tinymce_do_uninstall();
}

# ------------------------------------------------------
# Add the 'Uninstall' and 'Options' link to plugins list
# ------------------------------------------------------
function sp_tinymce_uninstall_option($actionlink, $plugin) {
         if ($plugin == 'tinymce-richtext/sp-tinymce-plugin.php') {
                 $url = SFADMINPLUGINS.'&amp;action=uninstall&amp;plugin='.$plugin.'&amp;sfnonce='.wp_create_nonce('forum-adminform_plugins');
                 $actionlink.= "&nbsp;&nbsp;<a href='".$url."' title='".__("Uninstall this plugin", "sp-tinymce")."'>".__("Uninstall", "sp-tinymce")."</a>";

                 $url = SFADMINCOMPONENTS.'&amp;tab=plugin&amp;admin=sp_tinymce_form&amp;save=sp_tinymce_save&amp;form=1';
                 $actionlink.= "&nbsp;&nbsp;<a href='".$url."' title='".__("Options", "sp-tinymce")."'>".__("Options", "sp-tinymce")."</a>";
         }
         return $actionlink;
}

function sp_tinymce_upgrade() {
         include_once(SPTMDIR.'sp-tinymce-install.php');
         sp_tinymce_do_upgrade();
}

# ----------------------------------------------
# Set GetText Localisation Domain
# ----------------------------------------------
function sp_tinymce_localisation() {
         sp_plugin_localisation('sp-tinymce');
}

# ----------------------------------------------
# Load the tinymce filter file
# ----------------------------------------------
function sp_tinymce_load_filters($editor) {
         if($editor == RICHTEXT) {
                 include_once(SPTMDIR.'library/sp-tinymce-filters.php');
         }
}

# ----------------------------------------------
# Load and Initialise this Editor if needed
# ----------------------------------------------
function sp_tinymce_load($editor) {
         if($editor == RICHTEXT) {
                 include_once(SPTMDIR.'tinymce/sp-tinymce-init.php');
         }
}

# ----------------------------------------------
# Display Textarea Input control
# ----------------------------------------------
function sp_tinymce_textarea($out, $areaid, $content, $editor, $tab) {
         if($editor == RICHTEXT) {
                 $out.= '<textarea  tabindex="'.$tab.'" class="spControl" name="'.$areaid.'" id="'.$areaid.'" cols="60" rows="12">'.$content.'</textarea>';
         }
         return $out;
}

# ----------------------------------------------
# Add Entry to SP Acknowledgements Popup
# ----------------------------------------------
function sp_tinymce_acknowledgement($ack) {
         $ack[] = __("TinyMCE text editor by Moxiecode Systems", "sp-tinymce").': <a href="http://www.moxiecode.com/">Moxiecode</a>';
         return $ack;
}

# ----------------------------------------------
# Add TinyMCE Admin Panel to Components
# ----------------------------------------------
function sp_tinymce_admin_menu() {
         $subpanels = array(
                 __("Editor (TinyMCE)", "sp-tinymce") => array('admin' => 'sp_tinymce_form', 'save' => 'sp_tinymce_save', 'form' => 1, 'id' => '')
         );
         sp_add_admin_subpanel('components', $subpanels);
}

# ----------------------------------------------
# Load the TinyMCE Options Admin Form
# ----------------------------------------------
function sp_tinymce_form() {
         include_once(SPTMDIR.'admin/sp-components-tinymce-form.php');
         sp_components_tinymce_options();
}

# ----------------------------------------------
# Save the TinyMCE Options Admin Form Data
# ----------------------------------------------
function sp_tinymce_save() {
         include_once(SPTMDIR.'admin/sp-components-tinymce-save.php');
         return sp_tinymce_options_save();

}

# ----------------------------------------------
# Action the Tinymce admin panel popup help
# ----------------------------------------------
function sp_tinymce_admin_help($file, $tag, $lang) {
     if ($tag == '[tinymce-options]' || $tag == '[tinymce-functions]') $file = SPTMDIR.'admin/sp-tinymce-admin-help.'.$lang;
     return $file;
}

# ----------------------------------------------
# Add tinymce to user profile editor option list
# ----------------------------------------------
function sp_tinymce_profile_option($edOpts, $userProfile) {
         $checked = ($userProfile->editor == RICHTEXT) ? $checked = 'checked="checked" ' : '';
         $edOpts.= '<p><label for="sf-richtext"><span class="spProfileRadioLabel">'.__("Rich text", 'sp-tinymce').' - '.RICHTEXTNAME.'</span></label><input type="radio" '.$checked.'name="editor" id="sf-richtext" value="'.RICHTEXT.'"/></p>';
         return $edOpts;
}

?>
